.. Amulet documentation master file, created by
   sphinx-quickstart on Fri Mar  4 18:51:07 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Amulet, a Juju test library
===========================

Amulet is a Python library for deploying, manipulating, and testing Juju
workloads (collections of related services).

With Amulet you can:

-  Deploy, relate, configure, and scale services imperatively
-  Deploy a preconfigured workload using a bundle file
-  Execute service actions and inspect the results
-  Run arbitrary commands against deployed units and inspect the results.


Table of Contents
-----------------

.. toctree::
   :maxdepth: 2

   installation
   quickstart
   modules


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

